; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| AI |------------------------------------------------------------------------
[Command]
Name = "AI_00"
Command = U, U, D, D, B, F, B, F, b, a
Time = 0

[Command]
Name = "AI_01"
Command = U, U, D, D, B, F, B, F, a, a
Time = 0

[Command]
Name = "AI_02"
Command = U, U, D, D, B, F, B, F, b, b
Time = 0

[Command]
Name = "AI_03"
Command = U, U, D, D, B, F, B, F, c, c
Time = 0

[Command]
Name = "AI_04"
Command = U, U, D, D, B, F, B, F, x, x
Time = 0

[Command]
Name = "AI_05"
Command = U, U, D, D, B, F, B, F, y, y
Time = 0

[Command]
Name = "AI_06"
Command = U, U, D, D, B, F, B, F, z, z
Time = 0

[Command]
Name = "AI_07"
Command = U, U, D, D, B, F, B, F, s, s
Time = 0

[Command]
Name = "AI_08"
Command = U, U, D, D, B, F, B, F, a, b
Time = 0

[Command]
Name = "AI_09"
Command = U, U, D, D, B, F, B, F, a, c
Time = 0

[Command]
Name = "AI_10"
Command = U, U, D, D, B, F, B, F, a, x
Time = 0

[Command]
Name = "AI_11"
Command = U, U, D, D, B, F, B, F, a, y
Time = 0

[Command]
Name = "AI_12"
Command = U, U, D, D, B, F, B, F, a, z
Time = 0

[Command]
Name = "AI_13"
Command = U, U, D, D, B, F, B, F, a, s
Time = 0

[Command]
Name = "AI_14"
Command = U, U, D, D, B, F, B, F, b, c
Time = 0

[Command]
Name = "AI_15"
Command = U, U, D, D, B, F, B, F, b, x
Time = 0

[Command]
Name = "AI_16"
Command = U, U, D, D, B, F, B, F, b, y
Time = 0

[Command]
Name = "AI_17"
Command = U, U, D, D, B, F, B, F, b, z
Time = 0

[Command]
Name = "AI_18"
Command = U, U, D, D, B, F, B, F, b, s
Time = 0

[Command]
Name = "AI_19"
Command = U, U, D, D, B, F, B, F, c, a
Time = 0

[Command]
Name = "AI_20"
Command = U, U, D, D, B, F, B, F, c, b
Time = 0

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "2QCF"
command = ~D, DF, F, D, DF, F
time = 30

[Command]
name = "2QCB"
command = ~D, DB, B, D, DB, B
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "CHICKEN WING"
command = ~$B, $D, $F, $U
time = 22

[Command]
name = "R CHICKEN WING"
command = ~$F, $D, $B, $U
time = 22

[Command]
name = "DP"
command = ~$F, $D, $F
time = 8

[Command]
name = "RDP"
command = ~$B, $D, $B
time = 8

[Command]
name = "QCF"
command = ~D, DF, F
time = 18

[Command]
name = "QCB"
command = ~D, DB, B
time = 18

[Command]
name = "HCF"
command = ~$B, $D, F
time = 22

[Command]
name = "HCB"
command = ~$F, $D, B
time = 22

[Command]
name = "dash"
command = F, F
time = 17
buffer.time = 4

[Command]
name = "focus dash"
command = ~F, F
time = 14
buffer.time = 7

[Command]
name = "dash back"
command = B, B
time = 17
buffer.time = 4

[Command]
name = "focus dash back"
command = ~B, B
time = 14
buffer.time = 7

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "FF2"     ;Required (do not remove)
command = ~F, F
time = 10
buffer.time = 8

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "BB2"     ;Required (do not remove)
command = ~B, B
time = 10
buffer.time = 8

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "Red Focus Attack"
command = x+start
time = 1
buffer.time = 12

[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "Ex Focus Attack"
command = y+b
time = 1
buffer.time = 12

;-------- 3

[Command]
name = "xyb"
command = x+y+b
time = 2
buffer.time = 3

[Command]
name = "xyb12"
command = x+y+b
time = 2
buffer.time = 12

[Command]
name = "xs"
command = x+s
time = 2
buffer.time = 2

[Command]
name = "xs12"
command = x+s
time = 2
buffer.time = 12

[Command]
name = "xyz"
command = x+y+z
time = 2
buffer.time = 3

[Command]
name = "abc"
command = a+b+c
time = 2
buffer.time = 3

;-------- 2

[Command]
name = "xy"
command = x+y
time = 2
buffer.time = 2

[Command]
name = "yz"
command = y+z
time = 2
buffer.time = 2

[Command]
name = "xz"
command = x+z
time = 2
buffer.time = 2

[Command]
name = "ab"
command = a+b
time = 2
buffer.time = 2

[Command]
name = "bc"
command = b+c
time = 2
buffer.time = 2

[Command]
name = "ac"
command = a+c
time = 2
buffer.time = 2

[Command]
name = "xa"
command = x+a
time = 2
buffer.time = 2

[Command]
name = "yb"
command = y+b
time = 2
buffer.time = 2

[Command]
name = "yb2"
command = y+b
time = 2
buffer.time = 2

[Command]
name = "yb12"
command = y+b
time = 2
buffer.time = 12

[Command]
name = "zc"
command = z+c
time = 2
buffer.time = 2

;-| Dir |---------------------------------------------------------
[Command]
name = "~F"
command = F
time = 1

[Command]
name = "~F"
command = ~F
time = 1

[Command]
name = "~B"
command = B
time = 1

[Command]
name = "~B"
command = ~B
time = 1


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "F"
command = F
time = 1

[Command]
name = "B"
command = B
time = 1

[Command]
name = "U"
command = U
time = 1

[Command]
name = "D"
command = D
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "a2"
command = a
time = 1
buffer.time = 2

[Command]
name = "a6"
command = a
time = 1
buffer.time = 6

[Command]
name = "b"
command = b
time = 1

[Command]
name = "b2"
command = b
time = 1
buffer.time = 2

[Command]
name = "b6"
command = b
time = 1
buffer.time = 6

[Command]
name = "c"
command = c
time = 1

[Command]
name = "c2"
command = c
time = 1
buffer.time = 2

[Command]
name = "c6"
command = c
time = 1
buffer.time = 6

[Command]
name = "x"
command = x
time = 1

[Command]
name = "x2"
command = x
time = 1
buffer.time = 2

[Command]
name = "x6"
command = x
time = 1
buffer.time = 6

[Command]
name = "y"
command = y
time = 1

[Command]
name = "y2"
command = y
time = 1
buffer.time = 2

[Command]
name = "y6"
command = y
time = 1
buffer.time = 6

[Command]
name = "z"
command = z
time = 1

[Command]
name = "z2"
command = z
time = 1
buffer.time = 2

[Command]
name = "z6"
command = z
time = 1
buffer.time = 6

[Command]
name = "start"
command = s
time = 1

[Command]
name = "Quick Get Up"
command = D
time = 1
buffer.time = 6

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "releasefwd"
command = ~F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "releaseback"
command = ~B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownforward"
command = /$DF
time = 1

[Command]
name = "fholdx"
command = /x
time = 1

[Command]
name = "fholdy"
command = /y
time = 1

[Command]
name = "fholdz"
command = /z
time = 1

[Command]
name = "fholda"
command = /a
time = 1

[Command]
name = "fholdb"
command = /b
time = 1

[Command]
name = "fholdc"
command = /c
time = 1

[Command]
name = "relx"
command = ~x
time = 1

[Command]
name = "rely"
command = ~y
time = 1

[Command]
name = "relz"
command = ~z
time = 1
buffer.time = 1

[Command]
name = "rela"
command = ~a
time = 1

[Command]
name = "relb"
command = ~b
time = 1

[Command]
name = "relc"
command = ~c
time = 1

[Command]
name = "relstart"
command = ~start
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold-x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold-y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 2
buffer.time = 2

[Command]
name = "hold-z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold-b"
command = /b
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "fholdstart"
command = /$start
time = 1

[Command]
name = "fholdabc"
command = /$a+b+c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -1, Taunt]
type = ChangeState
value = 10700
triggerall = var(59) <= 0
triggerall = command = "zc"
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2
trigger4 = var(31)

[State -1, Big Bang Typhoon]
type = Changestate
value = 4100
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(51) ;2QCF
triggerall = (helper(10371), var(30)) || (helper(10371), var(6)) || (helper(10371), var(16)) ;start
triggerall = statetype != a
triggerall = var(26) = 2 || var(26) = 3
triggerall = var(3) >= 500
trigger1 = ctrl
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = stateno = 40
trigger4 = stateno = 52
trigger5 = stateno = 53 && time > 2

[State -1, Space Opera Symphony]
type = Changestate
value = 4000
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(50) ;2QCF
triggerall = (helper(10371), var(30)) || (helper(10371), var(6)) || (helper(10371), var(16)) ;start
triggerall = statetype != a
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
trigger1 = ctrl
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = stateno = 40
trigger4 = stateno = 52
trigger5 = stateno = 53 && time > 2

[State -1, Hp Spectacle Romance]
type = Changestate
value = 3020
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(50) ;DP
triggerall = (helper(10371), var(2)) || (helper(10371), var(12)) ;HP
triggerall = statetype != a
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = var(31)
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Mp Spectacle Romance]
type = Changestate
value = 3010
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(50) ;DP
triggerall = (helper(10371), var(1)) || (helper(10371), var(11)) ;MP
triggerall = statetype != a
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = var(31)
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Lp Spectacle Romance]
type = Changestate
value = 3000
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(50) ;DP
triggerall = (helper(10371), var(0)) || (helper(10371), var(10)) ;LP
triggerall = statetype != a
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = var(31)
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

;--------------
[State -1, Red Focus]
type = ChangeState
value = 1600
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "xyb" || command = "xs"
triggerall = statetype != A
triggerall = power >= 500
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Ex Red Focus]
type = ChangeState
value = 1650
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = power >= 750
triggerall = command = "xyb12" || command = "xs12"
triggerall = statetype != A
trigger1 = var(31)
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, focus]
type = ChangeState
value = 1500
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "yb2"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Ex focus]
type = ChangeState
value = 1550
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = power >= 500
triggerall = command = "yb12"
triggerall = statetype != A
trigger1 = var(31)
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Ex Snake Strike]
type = ChangeState
value = 1230
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(42) ;DP
triggerall = (helper(10371), var(23)) || (helper(10371), var(24)) || (helper(10371), var(25)) ;LP
triggerall = statetype != a
triggerall = power >= 250
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Hp Snake Strike]
type = ChangeState
value = 1220
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(42) ;DP
triggerall = (helper(10371), var(2)) || (helper(10371), var(12)) ;HP
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger3 = stateno = 40
trigger4 = stateno = 52
trigger5 = stateno = 53 && time > 2

[State -1, Mp Snake Strike]
type = ChangeState
value = 1210
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(42) ;DP
triggerall = (helper(10371), var(1)) || (helper(10371), var(11)) ;MP
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Lp Snake Strike]
type = ChangeState
value = 1200
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(42) ;DP
triggerall = (helper(10371), var(0)) || (helper(10371), var(10)) ;LP
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Ex Messiah Kick]
type = ChangeState
value = 1130
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(26)) || (helper(10371), var(27)) || (helper(10371), var(28)) ;2K
triggerall = statetype != a
triggerall = power >= 250
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Hk Messiah Kick]
type = ChangeState
value = 1120
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(5)) || (helper(10371), var(15)) ;HK
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Mk Messiah Kick]
type = ChangeState
value = 1110
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(4)) || (helper(10371), var(14)) ;MK
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0 && (helper(10371), var(14) = 0)
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Lk Messiah Kick]
type = ChangeState
value = 1100
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(3)) || (helper(10371), var(13)) ;LK
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Ex Galactic Tornado]
type = ChangeState
value = 1030
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(23)) || (helper(10371), var(24)) || (helper(10371), var(25)) ;2P
triggerall = statetype != a
triggerall = power >= 250
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Hp Galactic Tornado]
type = ChangeState
value = 1020
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(2)) || (helper(10371), var(12)) ;HP
triggerall = statetype != a
trigger1 = var(30) > 1 && (helper(10371), var(12) = 0)
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Mp Galactic Tornado]
type = ChangeState
value = 1010
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(1)) || (helper(10371), var(11)) ;MP
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

[State -1, Lp Galactic Tornado]
type = ChangeState
value = 1000
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = helper(10371), var(40) ;QCF
triggerall = (helper(10371), var(0)) || (helper(10371), var(10)) ;LP
triggerall = statetype != a
trigger1 = var(30) > 1 && hitpausetime = 0
trigger2 = (stateno = [200, 499]) && var(56)
trigger3 = ctrl
trigger4 = stateno = 40
trigger5 = stateno = 52
trigger6 = stateno = 53 && time > 2

;-----------------------------
[State -1, Falcon Kick Steep]
type = ChangeState
value = 661
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "holddownforward"
triggerall = command = "b"
triggerall = vel x < -1
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Falcon Kick Diagonal]
type = ChangeState
value = 660
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "holddownforward"
triggerall = command = "b"
triggerall = vel x > -1
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Hk]
type = ChangeState
value = 655
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Hp]
type = ChangeState
value = 625
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Mk]
type = ChangeState
value = 645
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Mp]
type = ChangeState
value = 615
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Lk]
type = ChangeState
value = 635
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, J. Lp]
type = ChangeState
value = 605
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) >= 2.5
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Hk]
type = ChangeState
value = 650
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Hp]
type = ChangeState
value = 620
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Mk]
type = ChangeState
value = 640
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Mp]
type = ChangeState
value = 610
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Lk]
type = ChangeState
value = 630
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, N. J. Lp]
type = ChangeState
value = 600
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = abs(vel x) < 2.5
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Fragrance Palm]
type = ChangeState
value = 280
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "z"
triggerall = statetype != a
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Glory Kick]
type = ChangeState
value = 270
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "b"
triggerall = command = "holddownforward"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Vulture Kick]
type = ChangeState
value = 260
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "b"
triggerall = command = "holdfwd"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Cr. Hk]
type = ChangeState
value = 450
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Cr. Hp]
type = ChangeState
value = 420
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Cr. Mk]
type = ChangeState
value = 440
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Cr. Mp]
type = ChangeState
value = 410
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Cr. Lk Chain]
type = ChangeState
value = 431
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "a2"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = var(32)

[State -1, Cr. Lk]
type = ChangeState
value = 430
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = statetype != a
triggerall = !var(32)
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2
trigger4 = stateno = 430
trigger4 = time > 8 && time < 13

[State -1, Cr. Lp Chain]
type = ChangeState
value = 401
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "x2"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = var(32)

[State -1, Cr. Lp]
type = ChangeState
value = 400
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 7 && time < 13
trigger3 = stateno = 52
trigger4 = stateno = 53 && time > 2

[State -1, Throw]
type = ChangeState
value = 800
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "xa"
triggerall = statetype != a
triggerall = command != "holddown"
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2
trigger4 = (stateno = [200, 499]) && var(56)

[State -1, Close St. Hk Target Combo]
type = ChangeState
value = 290
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "c"
triggerall = statetype != a
trigger1 = var(35) > 1

[State -1, Close St. Hk]
type = ChangeState
value = 255
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Close St. Hp]
type = ChangeState
value = 225
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "z"
triggerall = command != "holddown" && command != "holdfwd"
triggerall = statetype != a
triggerall = p2bodydist x < 45
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Close St. Mk]
type = ChangeState
value = 245
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Close St. Mp]
type = ChangeState
value = 215
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Close St. Lk]
type = ChangeState
value = 235
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, Close St. Lp Chain]
type = ChangeState
value = 206
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "x2"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = var(32)

[State -1, Close St. Lp]
type = ChangeState
value = 205
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != a
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
trigger2 = stateno = 205
trigger2 = time > 7 && time < 13
trigger3 = stateno = 52
trigger4 = stateno = 53 && time > 2

[State -1, St. Hk]
type = ChangeState
value = 250
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, St. Hp]
type = ChangeState
value = 220
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, St. Mk]
type = ChangeState
value = 240
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, St. Mp]
type = ChangeState
value = 210
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, St. Lk]
type = ChangeState
value = 230
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "a"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = stateno = 52
trigger3 = stateno = 53 && time > 2

[State -1, St. Lp Chain]
type = ChangeState
value = 201
triggerall = var(59) <= 0
triggerall = !isHelper(10371)
triggerall = command = "x2"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = var(32)

[State -1, St. Lp]
type = ChangeState
value = 200
triggerall = var(59) <= 0
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype != a
trigger1 = ctrl
trigger2 = !movecontact
trigger2 = stateno = 200
trigger2 = time > 7 && time < 12
trigger3 = stateno = 52
trigger4 = stateno = 53 && time > 2

[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) <= 0
triggerall = statetype != a
triggerall = command = "dash"
trigger1 = ctrl

[State -1, Run Back]
type = ChangeState
value = 105
triggerall = var(59) <= 0
trigger1 = command = "dash back"
trigger1 = statetype = S
trigger1 = ctrl

;--------------------------------------------

;
;ȉAIGAIpǋLꏊ
;
[State -1, AI]
type = VarSet
TriggerAll = Var(59) <= 0
TriggerAll = RoundState = [1,2]
trigger1  = (Command = "AI_00") || (Command = "AI_01") || (Command = "AI_02") || (Command = "AI_03") 
trigger2  = (Command = "AI_04") || (Command = "AI_05") || (Command = "AI_06") || (Command = "AI_07")
trigger3  = (Command = "AI_08") || (Command = "AI_09") || (Command = "AI_10") || (Command = "AI_11") || (Command = "AI_12") || (Command = "AI_13") || (Command = "AI_14") || (Command = "AI_15")
trigger4  = (Command = "AI_16") || (Command = "AI_17") || (Command = "AI_18") || (Command = "AI_19") || (Command = "AI_20")
;----------------------------------------------------------------
Trigger5 = 1 ;AI펞N@؂Ƃ͐擪; 
;----------------------------------------------------------------
var(59) = 1;̒lύX邱ƂAIxݒ\(݂OFF:0 ON:1̂)
;----------------------------------------------------------------

[State -1, AI]@
Type = VarSet
TriggerAll = Var(59) >= 1@@@@ GAI
Trigger1 = RoundState >= 3 @@G퓬varXCb`؂B
V = 59
Value = 0

;----------------------------------------------------------------
[State -1,XCb`]
type = varset
Trigger1 = RoundState != 3
fv = 27
value= 1 ;̒lύX邱Ƃŏ̐䂪\
         ;0:off
         ;1:on(Default)

;----------------------------------------------------------------
[State -1,XCb`]
type = varset
Trigger1 = RoundState != 3
fv = 26
value= 1 ;̒lύX邱ƂŎ̒s̐䂪\
         ;0:offiȂj
         ;1:on(i͂̕pxA̗͂ƒpxiDefaultj)

;----------------------------------------------------------------
[State -1,ERI]
type = varset
Trigger1 = RoundState != 3
v = 26
value= 1 ;̒lύX邱ƂŎ̒s̐䂪\
         ;1:Xy[XIyVtHj[iDefaultj
         ;2:rbOo[^Ct[
         ;3:

;
;ȉAȂ
;

[State -1, ^bOp];
Type = VarSet
triggerall = var(59)
trigger1 = RoundState = 2
fvar(22) = 0 + (NumEnemy = 2 && EnemyNear(fvar(22)),life <= 0)
IgnoreHitPause = 1

[State -1, randamselect]
Type = VarRandom
Trigger1 = 1
V = 57
Range = 0,99

;
;
;
;i肪ȏŃ_Eɂ̊mŁi̗͂ႢƂ߂jj
[State -1,]
type = ChangeState
value = 10700
TriggerAll = var(59) > 0
TriggerAll = fvar(26) >= 1
TriggerAll = RoundState = 2
TriggerAll = statetype != A
TriggerAll = P2StateNo = [5070,5120]
;ʏ
TriggerAll = ctrl
TriggerAll = P2BodyDist X > 150
trigger1 = Life >= LifeMax*0.5
Trigger1 = Random < 50
trigger2 = Life >= LifeMax*0.3
Trigger2 = Random < 10

;
[State -1,]
type = ChangeState
value = 10700
TriggerAll = var(59) > 0
TriggerAll = fvar(27) = 1
TriggerAll = Alive
TriggerAll = RoundState = 3
TriggerAll = Win && (!WinTime)
triggerall = statetype != A
triggerAll = ctrl
trigger1 = stateno != 10700
Trigger1 = random < 100

;AIx~
[State -3,AIx~]
type = varset
TriggerAll = var(59) > 0
TriggerAll = fvar(27) = 1
trigger1 = RoundState = 3
trigger1 = stateno = 10700
v = 59
value= 0


;
;؂Ԃ⊄荞݁Ao[TȂ
;

;---------------------------------------------------------------------------
;oT
;---------------------------------------------------------------------------

[State -1, Throw]
type = ChangeState
value = 800
TriggerAll = var(59) > 0
triggerall = alive
triggerall = ctrl
triggerall = EnemyNear(fvar(22)),MoveType != H
triggerall = EnemyNear(fvar(22)),StateType != A
triggerall = statetype != A
triggerall = ctrl
triggerall = p2bodydist X < 35
;ʏ
TriggerAll = RoundState = 2
TriggerAll = Random < 350
Trigger1 = (PrevStateNo=[5000,5270])
Trigger2 = (PrevStateNo=[120,159])

;---------------------------------------------------------------------------
;荞݂Ԃ
;---------------------------------------------------------------------------

;rbOo[
[State -1, Big Bang Typhoon]
type = Changestate
value = 4100
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = (StateType != A)
triggerall = var(26) = 2 || var(26) = 3
triggerall = var(3) >= 500
triggerall = ctrl
;ʏ
trigger1 = EnemyNear(fvar(22)),HitDefAttr = SCA,NA,SA,HA
trigger1 = p2bodydist X <= 200
Trigger1 = P2BodyDist Y >= -100
trigger1 = random <= 200


;Xy[XIy
[State -1, Space Opera Symphony]
type = Changestate
value = 4000
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = (StateType != A)
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
triggerall = ctrl
;ʏ
trigger1 = EnemyNear(fvar(22)),HitDefAttr = SCA,NA,SA,HA
trigger1 = p2bodydist X = [0, 60]
Trigger1 = P2BodyDist Y >= -80
;R{ɎgȂ܂ܑ̗̓oCp
trigger1 = Life <= LifeMax*0.3
trigger1 = random <= 300


;EX~
[State -1, Ex Messiah Kick]
type = ChangeState
value = 1130
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = (StateType != A)
triggerall = power >= 250
triggerall = ctrl
;ʏ
trigger1 = EnemyNear(fvar(22)),HitDefAttr = SCA,NA,SA,HA
trigger1 = p2bodydist X <= 60
trigger1 = random <= 250

;
;R{Lq
;
;====================================================================================
;sϐ Zbg
;====================================================================================
[State -1,reset1]
type = varset
triggerall = var(58)
trigger1 = p2movetype != H || p2statetype = L
;trigger1 = (var(58) != [21,29]) && (var(58) != 3)
; && (var(58) != [41,44])
;rōUH璆f
trigger2 = statetype = L || movetype = H
;R{󂩂āA肪Ă悤Ȃ璆f
trigger3 = P2stateno=[10,110] 
Trigger4 = !Alive
;I؂
trigger5 = RoundState != 2
var(58) = 999

[State -1,reset]
type = varset
trigger1 = var(58) = 999
var(58) = 0

[State -1, Debug1]
Type = DisplayToClipBoard
Trigger1 = 1
Text = "var(58) = %d,back%d,front%d,p2X%d,p2Y%d,Py%f \n"
Params = var(58),backedgebodydist,frontedgebodydist,p2bodydist X,p2bodydist Y,pos y
;Text = "var(58) = %d,Px%f,Py%f,back%d,front%d,p2X%d \n"
;Params = var(58),pos x,pos y,backedgebodydist,frontedgebodydist,p2bodydist X
IgnoreHitPause = 1

;====================================================================================
;{R{@1-
;====================================================================================
;====================================================================================
;R{ڍspLq
;====================================================================================
;t@R[ninj
;tQ[WL
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
trigger1 = StateNo = 660
trigger2 = StateNo = 661
;łɑ
trigger3 = StateNo = 650
trigger4 = StateNo = 655
trigger5 = StateNo = 625
trigger6 = StateNo = 640
trigger7 = StateNo = 645
var(58) = 11

;tQ[WȂ
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 660
trigger2 = StateNo = 661
;łɑ
trigger3 = StateNo = 650
trigger4 = StateNo = 655
trigger5 = StateNo = 625
trigger6 = StateNo = 640
trigger7 = StateNo = 645
var(58) = 1

;JK󒆃qbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype = A
trigger1 = StateNo = 655
var(58) = 31

;ߋPqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 225
var(58) = 41

;Kqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 430
var(58) = 51

;Kqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 440
trigger1 = power >= 700
var(58) = 61

;ߗKqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 245
var(58) = 71

;Kqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
trigger1 = StateNo = 250
var(58) = 81


;EX~qbgiER܂Ōq̂͒nqbĝ݁j
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 1130
trigger2 = StateNo = 1131
var(58) = 101

;Zrqbg
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 1520
trigger2 = StateNo = 1530
var(58) = 151

;~qbgihpj
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = movehit
triggerAll = P2statetype != A
trigger1 = StateNo = 1100
trigger2 = StateNo = 1101
trigger3 = StateNo = 1110
trigger4 = StateNo = 1111
trigger5 = StateNo = 1120
trigger6 = StateNo = 1121
var(58) = 201


;====================================================================================
;ȉAR{̋Lq
;====================================================================================
;====================================================================================
;{R{@1-@t@R[nqbg
;====================================================================================

[State -1, Close St. Lk]
type = ChangeState
value = 235
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = abs(p2bodydist x) < 45
;ʏ
triggerall = ctrl
triggerall = var(58) = 1
trigger1 = var(58) := 2

[State -1, Close St. Hp]
type = ChangeState
value = 225
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = p2bodydist x < 45
;ʏ
triggerall = ctrl
triggerall = var(58) = 2
trigger1 = var(58) := 3

[State -1, Hp Galactic Tornado]
type = ChangeState
value = 1020
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = p2bodydist x < 45
;ʏ
triggerall = var(30) > 1
triggerall = var(58) = 3
;Ȃ͂ǁArŗ܂ĉʒ[̎p
trigger1 = var(3) >= 500
trigger1 = var(26) = 1 || var(26) = 3
trigger1 = var(58) := 4
trigger1 = frontedgebodydist < 70
;ȊO
trigger2 = var(58) := 999

[State -1, Space Opera Symphony]
type = Changestate
value = 4000
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
triggerall = p2bodydist x < 55
;ʏ
triggerall = ctrl
triggerall = var(58) = 4
trigger1 = var(58) := 999

;--------------------
;ERP[g
;--------------------
[State -1, Close St. Lk]
type = ChangeState
value = 235
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = abs(p2bodydist x) < 45
;ʏ
triggerall = ctrl
triggerall = var(58) = 11
trigger1 = var(58) := 12

[State -1, Close St. Hk Target Combo]
type = ChangeState
value = 290
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = var(35) > 1
triggerall = var(58) = 12
trigger1 = var(58) := 13

[State -1, Space Opera Symphony]
type = Changestate
value = 4000
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
;ʏ
triggerall = ctrl
triggerall = var(58) = 13
trigger1 = var(58) := 999


;====================================================================================
;{R{@31-@J󒆃qbg
;====================================================================================

;--------------------
;Q[WL
;--------------------
[State -1, Ex Snake Strike]
type = ChangeState
value = 1230
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = power >= 250
;ʏ
triggerall = ctrl
triggerall = var(58) = 31
trigger1 = var(58) := 999

;--------------------
;Q[WȂ
;--------------------
[State -1, Hp Snake Strike]
type = ChangeState
value = 1220
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = ctrl
triggerall = var(58) = 31
trigger1 = var(58) := 999


;====================================================================================
;{R{@41-@ߋPnqbg
;====================================================================================

[State -1, Hp Galactic Tornado]
type = ChangeState
value = 1020
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = var(30) > 1
triggerall = var(58) = 41
;ERQ[W܂Ăꍇ
trigger1 = var(26) = 1 || var(26) = 3
trigger1 = var(3) >= 500
trigger1 = var(58) := 45
;XpRQ[W܂Ăꍇ
trigger2 = power >= 1000
trigger2 = var(58) := 42

[State -1, Lp Galactic Tornado]
type = ChangeState
value = 1000
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = ctrl
triggerall = var(58) = 42
triggerall = frontedgebodydist < 70
trigger1 = var(58) := 43

[State -1, Hp Spectacle Romance]
type = Changestate
value = 3020
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = power >= 1000
;ʏ
triggerall = var(31)
triggerall = var(58) = 43
trigger1 = var(58) := 999

[State -1, Space Opera Symphony]
type = Changestate
value = 4000
;ʏ
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
;ʏ
triggerall = ctrl
triggerall = var(58) = 45
triggerall = frontedgebodydist < 120
trigger1 = var(58) := 999

;====================================================================================
;{R{@51-@Knqbg
;====================================================================================
[State -1, Lp Galactic Tornado]
type = ChangeState
value = 1000
TriggerAll = var(59) != 0
triggerall = var(18) != 2
triggerall = statetype != A
;ʏ
;triggerall = ctrl
triggerall = var(30) > 1
triggerall = var(58) = 51
trigger1 = var(58) := 999

;====================================================================================
;{R{@61-@EX͒ǌ
;====================================================================================
[State -1, Ex Galactic Tornado]
type = ChangeState
value = 1030
TriggerAll = var(59) != 0
triggerall = var(18) != 2
triggerall = power >= 250
triggerall = statetype != A
;ʏ
;triggerall = ctrl
triggerall = var(30) > 1
triggerall = var(58) = 61
trigger1 = var(58) := 999

;====================================================================================
;{R{@71-@͒ǌ
;====================================================================================

[State -1, Hp Galactic Tornado]
type = ChangeState
value = 1020
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = var(30) > 1
triggerall = var(58) = 71
trigger1 = var(58) := 999

;====================================================================================
;{R{@81-@Kqbg
;====================================================================================
;ERQ[WȂ
[State -1, Hp Snake Strike]
type = ChangeState
value = 1220
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = ctrl
triggerall = var(58) = 81
trigger1 = (var(26) = 2) || (var(3) < 500)
trigger1 = var(58) := 999

[State -1, St. Hk]
type = ChangeState
value = 250
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = ctrl
triggerall = var(58) = 81
triggerAll = movehit
trigger1 = var(58) := 82

[State -1, Space Opera Symphony]
type = Changestate
value = 4000
;ʏ
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
;ʏ
triggerall = ctrl
triggerall = var(58) = 82
;triggerall = frontedgebodydist < 120
trigger1 = var(58) := 999

;====================================================================================
;ZrLR{@101-@EX~qbg
;====================================================================================
[State -1, Ex focus]
type = ChangeState
value = 1550
TriggerAll = var(59) != 0
triggerall = power >= 500
triggerall = statetype != A
;ʏ
triggerall = (ctrl) || (var(31))
triggerall = var(58) = 102
;ER_鎞~E
trigger1 = (var(3) >= 500) || (P2Life < 40)
trigger1 = var(58) := 103

;ERQ[W鎞
[State -1, Space Opera Symphony]
type = Changestate
value = 4000
;ʏ
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = var(26) = 1 || var(26) = 3
triggerall = var(3) >= 500
;ʏ
triggerall = ctrl
triggerall = var(58) = 104
triggerall = frontedgebodydist < 120
trigger1 = var(58) := 999

;Q[WȂ
[State -1, Mp Snake Strike]
type = ChangeState
value = 1210
TriggerAll = var(59) != 0
triggerall = statetype != A
;ʏ
triggerall = ctrl
triggerall = var(58) = 104
trigger1 = var(58) := 999

;====================================================================================
;Zrqbg@151-@ߋP[g
;====================================================================================
[State -1, Close St. Hp]
type = ChangeState
value = 225
TriggerAll = var(59) != 0
triggerall = statetype != A
triggerall = p2bodydist x < 45
;ʏ
triggerall = ctrl
triggerall = var(58) = 151
trigger1 = var(58) := 41


;====================================================================================
;ʏUK[hꂽɋ͂Ƃ܂ɋ~
;====================================================================================
[State -1, Lp Galactic Tornado]
type = ChangeState
value = 1000
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = MoveGuarded
triggerAll = P2statetype != A
trigger1 = var(30) > 1
Trigger1 = Random < 300

[State -1, Lk Messiah Kick]
type = ChangeState
value = 1100
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
triggerAll = MoveGuarded
triggerAll = P2statetype != A
trigger1 = var(30) > 1
Trigger1 = Random < 100

;
;K[hLq
;
;Kb`K`K[h
[State -3]
Type = VarSet
TriggerAll = fvar(23) = 0
Trigger1 = EnemyNear,NumHelper > 0
trigger1 = RoundState = 2
V = 53
Value = EnemyNear,NumHelper

[State -1, h]
Type = ChangeState
Value = 120
triggerAll = Var(59) > 0
triggerall = RoundState = 2
TriggerAll = Alive
triggerAll = Ctrl
trigger1 = InGuardDist
trigger1 =! EnemyNear(fvar(22)),HitDefAttr = ,NT,ST,HT 
trigger2 = Enemy,NumHelper > 0
trigger2 = Enemy,NumHelper > fvar(23)
trigger2 = InGuardDist

;---------------------------------------------------------------------------
[State -1,ڍs]
type = null;ChangeState
value = 12
TriggerAll = Var(59) > 0
TriggerAll = RoundState = 2
TriggerAll = StateType = C
TriggerAll = Ctrl
TriggerAll = EnemyNear(fvar(22)),StateType = A
TriggerAll = P2BodyDist X < 60
Trigger1 = Random < (750)

;---------------------------------------------------------------------------
;ʏ݈ڍs
[State -1, ݈ڍs]
type = ChangeState
value = 10
TriggerAll = Var(59) > 0
TriggerAll = RoundState = 2
Trigger1 = EnemyNear(fvar(22)),StateType = S || EnemyNear(fvar(22)),StateType = C
Trigger1 = (StateType = S) && (Time > 30)
Trigger1 = Ctrl
Trigger1 = P2BodyDist X = [0,40]
Trigger1 = Random < (550)


;
;΋ENU߁EԂςȂ
;
;====================================================================================
;΋
;====================================================================================
[State -1, Lp Snake Strike]
type = ChangeState
value = 1200
TriggerAll = Var(59) > 0
triggerall = alive
TriggerAll = RoundState = 2
TriggerAll = var(58) = 0
triggerall = statetype != A
triggerall = ctrl
trigger1 = P2Dist Y <= -150
trigger1 = P2BodyDist X < 60
Trigger1 = EnemyNear(fvar(22)),StateType = A
trigger1 = Random < 100

[State -1, Mp Snake Strike]
type = ChangeState
value = 1210
TriggerAll = Var(59) > 0
triggerall = alive
TriggerAll = RoundState = 2
TriggerAll = var(58) = 0
triggerall = statetype != A
triggerall = ctrl
trigger1 = P2Dist Y = [-200, -100]
trigger1 = P2BodyDist X = [20, 80]
Trigger1 = EnemyNear(fvar(22)),StateType = A
trigger1 = Random < 100

[State -1, Hp Snake Strike]
type = ChangeState
value = 1220
TriggerAll = Var(59) > 0
triggerall = alive
TriggerAll = RoundState = 2
TriggerAll = var(58) = 0
triggerall = statetype != A
triggerall = ctrl
trigger1 = P2Dist Y = [-200, -100]
trigger1 = P2BodyDist X = [30, 90]
Trigger1 = EnemyNear(fvar(22)),StateType = A
trigger1 = Random < 100

;====================================================================================
;NU
;====================================================================================
;Zr
[State -1, focus]
type = ChangeState
value = 1500
TriggerAll = Var(59) > 0
triggerall = alive
TriggerAll = RoundState = 2
TriggerAll = var(58) = 0
triggerall = statetype != A
triggerall = ctrl
;NUߋʏ
triggerAll = ctrl = 1
TriggerAll = EnemyNear(fvar(22)),StateType = L
;ߋȂ炻̊m
trigger1 = P2BodyDist X = [10, 50]
trigger1 = Random < 150


;====================================================================================
;Ԃ
;====================================================================================

;
;ړs
;
;_E̋l
[State -1, Glory Kick]
type = ChangeState
value = 270
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
;ʏ
triggerAll = ctrl
triggerAll = EnemyNear(fvar(22)),StateType = L
trigger1 = P2BodyDist X = [80, 125]

;̏ꍇANUߓpɈ񉺂
[State -1, Run Back]
type = ChangeState
value = 105
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
;ʏ
triggerAll = ctrl
triggerAll = EnemyNear(fvar(22)),StateType = L
trigger1 = P2BodyDist X <= 10

;t@R[_̑OWv
[State -1,Jump]
type = ChangeState
value = 41
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
;ʏ
triggerAll = ctrl
trigger1 = P2BodyDist X = [45, 160]
Trigger1 = EnemyNear(fvar(22)),statetype != A
trigger1 = Random < 50

;̋l
[State -1, Run Fwd]
type = ChangeState
value = 100
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
;ʏ
triggerAll = ctrl
trigger1 = P2BodyDist X >= 130
Trigger1 = EnemyNear(fvar(22)),movetype != A
trigger1 = Random < 75

;
;Z
;

;====================================================================================
;n㎞
;====================================================================================

;====================================================================================
;ߋ
;====================================================================================
[State -1, Cr. Lk]
type = ChangeState
value = 430
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = !var(32)
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 40
Trigger1 = EnemyNear(fvar(22)),statetype != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 100

[State -1, Close St. Lp]
type = ChangeState
value = 205
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
Trigger1 = P2BodyDist Y >= -60
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 40

[State -1, Close St. Mk]
type = ChangeState
value = 245
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
triggerall = abs(p2bodydist x) < 45
trigger1 = ctrl
Trigger1 = P2BodyDist Y >= -70
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 60

[State -1, Close St. Hp]
type = ChangeState
value = 225
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = p2bodydist x < 45
trigger1 = ctrl
Trigger1 = P2BodyDist Y >= -100
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

;====================================================================================
;ߋ
;====================================================================================
[State -1, St. Lp]
type = ChangeState
value = 200
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
trigger1 = ctrl
Trigger1 = P2BodyDist X = [46, 60]
Trigger1 = P2BodyDist Y >= -60
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 40


[State -1, St. Hp]
type = ChangeState
value = 220
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
trigger1 = ctrl
Trigger1 = P2BodyDist X = [46, 55]
Trigger1 = P2BodyDist Y = [-100, -40]
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 70

[State -1, St. Hk]
type = ChangeState
value = 250
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
trigger1 = ctrl
Trigger1 = P2BodyDist X = [46, 75]
Trigger1 = P2BodyDist Y >= -100
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

[State -1, Fragrance Palm]
type = ChangeState
value = 280
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [50, 80]
Trigger1 = P2BodyDist Y >= -60
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 50

;i_
[State -1, Vulture Kick]
type = ChangeState
value = 260
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 80
Trigger1 = EnemyNear(fvar(22)),statetype = C
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

;====================================================================================
;ߋ`
;====================================================================================
[State -1, Cr. Mk]
type = ChangeState
value = 440
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 65
Trigger1 = EnemyNear(fvar(22)),StateType != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

[State -1, Cr. Hk]
type = ChangeState
value = 450
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [80, 100]
Trigger1 = EnemyNear(fvar(22)),StateType = S
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 40

[State -1, Lk Messiah Kick]
type = ChangeState
value = 1100
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 90
Trigger1 = P2BodyDist Y >= -40
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 100

[State -1, Mk Messiah Kick]
type = ChangeState
value = 1110
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [80, 120]
Trigger1 = P2BodyDist Y >= -60
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 100

[State -1, Hk Messiah Kick]
type = ChangeState
value = 1120
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [110, 190]
Trigger1 = P2BodyDist Y >= -70
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 100

[State -1, Lp Galactic Tornado]
type = ChangeState
value = 1000
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 80
Trigger1 = P2BodyDist Y >= -50
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

[State -1, Hp Galactic Tornado]
type = ChangeState
value = 1020
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [70, 150]
Trigger1 = P2BodyDist Y >= -50
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75


[State -1, Cr. Hp]
type = ChangeState
value = 420
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype != A
triggerall = var(18) != 2
trigger1 = ctrl
Trigger1 = P2BodyDist X = [80, 160]
Trigger1 = EnemyNear(fvar(22)),StateType != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 50

;====================================================================================
;󒆎
;====================================================================================

;====================================================================================
;Βn
;====================================================================================
;t@R[D

[State -1, Falcon Kick Diagonal]
type = ChangeState
value = 660
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = vel x > -1
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 100
Trigger1 = EnemyNear(fvar(22)),statetype != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 125

[State -1, Falcon Kick Steep]
type = ChangeState
value = 661
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = vel x < -1
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 20
Trigger1 = EnemyNear(fvar(22)),statetype != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 50

[State -1, J. Hp]
type = ChangeState
value = 625
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = var(18) != 2
triggerall = abs(vel x) >= 2.5
;莞
triggerall = vel y > 0
triggerall = pos y < -30
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 45
Trigger1 = P2BodyDist Y <= 80
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

[State -1, J. Hk]
type = ChangeState
value = 655
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = abs(vel x) >= 2.5
;莞
triggerall = pos y < -30
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 45
Trigger1 = P2BodyDist Y = [-90, 30]
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 125

[State -1, J. Mk]
type = ChangeState
value = 645
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = abs(vel x) >= 2.5
;莞
triggerall = pos y < -30
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 65
Trigger1 = P2BodyDist Y = [-60, 30]
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 125


;====================================================================================
;΋
;====================================================================================
[State -1, J. Mp]
type = ChangeState
value = 615
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
TriggerAll = Alive
triggerAll = statetype = A
triggerall = var(18) != 2
triggerall = abs(vel x) >= 2.5
;莞
triggerall = pos y < -30
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 40
Trigger1 = P2BodyDist Y = [-90, 0]
Trigger1 = EnemyNear(fvar(22)),StateType != A
Trigger1 = EnemyNear(fvar(22)),StateType != L
Trigger1 = Random < 75

